Learn R Programming

bibs (version 1.1.1)

fatigue: Fatigue data

Description

A set of 101 observations obtained by Birnbaum and Saunders(1969) from fatigue life of 6061-T6 aluminum coupons cut parallel to the direction of rolling and oscillated at 18 cycles per second (cps).

Usage

data(fatigue)

Arguments

Format

A text file with 1 column.

References

Z. W. Birnbaum and S. C. Saunders 1969. Estimation for a family of life distributions with applications to fatigue. Journal of Applied Probability, 328-347.

Examples

Run this code
# NOT RUN {
data(fatigue)
# }

Run the code above in your browser using DataLab