Jeffreysbs: Computing the Bayesian estimators of the Birnbaum-Saunders (BS) distribution.
Description
Computing the Bayesian estimators of the BS distribution based on approximated Jeffreys prior proposed by Achcar (1993). The approximated Jeffreys piors is
\(\pi_{j}(\alpha,\beta)\propto\frac{1}{\alpha\beta}\sqrt{\frac{1}{\alpha^2}+\frac{1}{4}}\).
Usage
Jeffreysbs(x, CI = 0.95, M0 = 800, M = 1000)
Arguments
x
Vector of observations.
CI
Confidence level for constructing percentile and asymptotic confidence intervals. That is 0.95 by default.
M0
The number of sampler runs considered as burn-in.
M
The number of total sampler runs.
Value
A list including summary statistics of a Gibbs sampler for the Bayesian inference including point estimation for the parameter, its standard error, and the corresponding \(100(1-\alpha)\%\) credible interval, goodness-of-fit measures, asymptotic \(100(1-\alpha)\%\) confidence interval (CI) and corresponding standard errors, and Fisher information matix.
References
J. A. Achcar 1993. Inferences for the Birnbaum-Saunders fatigue life model using Bayesian methods, Computational Statistics \& Data Analysis, 15 (4), 367-380.